# -*- coding: UTF-8 -*-
'''
@Author  ：程序员晚枫，B站/抖音/微博/小红书/公众号
@WeChat     ：CoderWanFeng
@Blog      ：www.python-office.com
@Date    ：2023/2/3 21:49 
@Description     ：
'''
import base64

from pobaidu.lib.CommonUtils import get_error_info


def get_img_base64(img_path):
    with open(img_path, 'rb') as fp:
        img_base64 = base64.b64encode(fp.read()).decode()
        return img_base64
    return None





import unittest

from pobaidu.api.face import face_merge

from pobaidu.core.ImageProcess import ImageProcess

from pobaidu.api.imageprocess import selfieAnime, colourize


class TestBaidu(unittest.TestCase):
    def test_selfie_anime(self):
        selfieAnime(filePath=r'file/img_cartoon.jpg')

    def test_colourize(self):
        res = colourize(img_path=r'file/girl.jpg', output_path=r'./output/res.jpg')
        print(res)

    def test_face_merge(self):
        face_merge(base_img_path=r'C:\Users\Lenovo\Desktop\temp\刘德华.jpg',
                   face_img_path=r'C:\Users\Lenovo\Desktop\temp\6606c755dd77427fb06e2e36eef969f2.png')



# -*- coding: UTF-8 -*-
'''
@Author  ：程序员晚枫，B站/抖音/微博/小红书/公众号
@WeChat     ：CoderWanFeng
@Blog      ：www.python-office.com
@Date    ：2023/2/2 23:39 
@Description     ：
'''

import base64

import requests
import json

from pobaidu.core.Face import Face
from pobaidu.lib.Const import FACE_URL
from pobaidu.lib.FileUtils import get_img_base64


def get_Face(configPath):
    face_instance = Face()
    face_instance.set_config(configPath)
    return face_instance


def face_merge(base_img_path='', face_img_path='', output_path=r'./output/face_merge.jpg', configPath=None):
    face_instance = get_Face(configPath)
    url = FACE_URL + face_instance.get_access_token()
    base_img = get_img_base64(base_img_path)
    face_img = get_img_base64(face_img_path)
    payload = json.dumps({
        "image_target": {
            "image": face_img,
            "image_type": "BASE64",
            "quality_control": "NONE"
        },
        "image_template": {
            "image": base_img,
            "image_type": "BASE64"
        },
        "merge_degree": "COMPLETE"
    })
    headers = {
        'Content-Type': 'application/json'
    }

    response = requests.request("POST", url, headers=headers, data=payload)

    # print(json.loads(response.text)['result']['merge_image'])
    res_img = json.loads(response.text)['result']['merge_image']
    # 解码图片
    imgdata = base64.b64decode(res_img)
    # print(imgdata)
    # save_file_content(filePath=output_path, fileData=imgdata)
    # # 将图片保存为文件
    with open(output_path, 'wb') as f:
        f.write(imgdata)



from pobaidu.api import imageprocess
from pobaidu.api import face
from pobaidu.lib.Const import SPLIT_LINE

print(SPLIT_LINE)
print('【pobaidu库】，功能持续更新中')
print('使用有问题 or 提交你的功能需求 or 参与项目开发')
print('1、请+【项目交流群】：http://t.cn/A65MiFvH')
print('2、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/pobaidu')
print(SPLIT_LINE)
